| biogeme_catalog_controller | R Documentation |
Catalog controllers select the same named specification in every catalog that shares the controller. The object remains an R specification until the complete expression is compiled to native Biogeme.
biogeme_catalog_controller(name, specification_names, selected_name = NULL)
catalog_controller(name, specification_names, selected_name = NULL)
name |
Controller name. |
specification_names |
Ordered, unique catalog specification names. |
selected_name |
Optional specification selected before native compilation. |
A neutral catalog controller.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.