biogeme_database_extract_rows: Extract observations from a Biogeme database

View source: R/database.R

biogeme_database_extract_rowsR Documentation

Extract observations from a Biogeme database

Description

This is the R equivalent of native Database.extract_rows(). Indices are deliberately one-based, as in the rest of the R interface, and the original row identifiers are retained in the returned database.

Usage

biogeme_database_extract_rows(database, indices)

database_extract_rows(database, indices)

Arguments

database

A biogeme_database object.

indices

Unique positive one-based row indices, in the order to keep.

Value

A new biogeme_database containing the selected observations.


rbiogeme documentation built on Sept. 29, 2026, 5:09 p.m.