biogeme_database_nrow: Return the number of rows currently represented by a database

View source: R/database.R

biogeme_database_nrowR Documentation

Return the number of rows currently represented by a database

Description

Return the number of rows currently represented by a database

Usage

biogeme_database_nrow(database)

Arguments

database

A biogeme_database object.

Value

An integer, or NA until lazy native filters are materialised.


rbiogeme documentation built on Sept. 29, 2026, 5:09 p.m.