biogeme_database_row_ids: Return the original row identifiers of a Biogeme database

View source: R/database.R

biogeme_database_row_idsR Documentation

Return the original row identifiers of a Biogeme database

Description

Return the original row identifiers of a Biogeme database

Usage

biogeme_database_row_ids(database)

Arguments

database

A biogeme_database object.

Value

A character vector of row identifiers.


rbiogeme documentation built on Sept. 29, 2026, 5:09 p.m.