biogeme_error_details: Return the diagnostic details attached to a Biogeme error

View source: R/errors.R

biogeme_error_detailsR Documentation

Return the diagnostic details attached to a Biogeme error

Description

Return the diagnostic details attached to a Biogeme error

Usage

biogeme_error_details(error)

Arguments

error

A condition inheriting from biogeme_error.

Value

A named list with operation, suggestion, parent, and optional Python traceback details.


rbiogeme documentation built on Sept. 29, 2026, 5:09 p.m.