biogeme_function: Create a Biogeme function node

View source: R/expressions.R

biogeme_functionR Documentation

Create a Biogeme function node

Description

This constructor is intentionally generic so that new public Biogeme functions can be added without evaluating the expression in R.

Usage

biogeme_function(operator, args = list(), ...)

Arguments

operator

Native Biogeme function/operator name.

args

A list of scalar values or Biogeme expressions.

Value

A Biogeme expression.


rbiogeme documentation built on Sept. 29, 2026, 5:09 p.m.