biogeme_python: Initialize and return the Python interpreter used by rbiogeme

View source: R/runtime.R

biogeme_pythonR Documentation

Initialize and return the Python interpreter used by rbiogeme

Description

Initialize and return the Python interpreter used by rbiogeme

Usage

biogeme_python()

Value

A reticulate Python configuration object. If no interpreter was selected, reticulate may provision the configured native requirement in its managed environment.


rbiogeme documentation built on Sept. 29, 2026, 5:09 p.m.