biogeme_sampling_partition: Define a native Biogeme sampling partition

View source: R/sampling.R

biogeme_sampling_partitionR Documentation

Define a native Biogeme sampling partition

Description

Stores the strata and sample sizes used by Biogeme's sampling-of-alternatives API. The segments must cover full_set, and no sample size may exceed the size of its segment.

Usage

biogeme_sampling_partition(segments, sample_sizes, full_set = NULL)

Arguments

segments

A non-empty list of disjoint integer alternative-ID vectors.

sample_sizes

One positive sample size for each segment.

full_set

Optional integer vector containing the complete partition universe.

Value

A declarative biogeme_sampling_partition object. Native Biogeme performs the actual random sampling when the model is estimated.

See Also

sampled_alternatives_model()


rbiogeme documentation built on Sept. 29, 2026, 5:09 p.m.