| simulate | R Documentation |
Simulate named native Biogeme expressions at fixed estimates
simulate(model, expressions = NULL, beta, control = NULL, database = NULL)
model |
A |
expressions |
Optional named list of expressions. When omitted, the
model's |
beta |
A |
control |
Optional |
database |
Optional scenario database. It may be a
|
expressions is a named list of complete symbolic expressions. When it is
omitted, the model's simulations list is used. Native Biogeme evaluates
these expressions at the supplied parameter values and returns ordinary R
data frames.
A biogeme_simulation object containing a data frame of values.
## Not run:
simulation_model <- biogeme_model(
database,
formula = choice_log_probability,
simulations = list(probability = choice_probability)
)
simulated <- simulate(
simulation_model,
beta = fit,
control = biogeme_control(output_directory = tempfile("rbiogeme-sim-"))
)
as.data.frame(simulated)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.