simulate_bayesian: Simulate formulas over Bayesian posterior draws

View source: R/simulation.R

simulate_bayesianR Documentation

Simulate formulas over Bayesian posterior draws

Description

Evaluates named simulation formulas over native Bayesian posterior draws and returns the native mean and quantile summaries without exposing PyMC objects.

Usage

simulate_bayesian(model, bayesian_results, expressions = NULL,
  percentage_of_draws_to_use = 10, lower_quantile = 0.025,
  upper_quantile = 0.975, control = NULL)

Arguments

model

A biogeme_model.

bayesian_results

A biogeme_bayesian_fit or a path to a native NetCDF Bayesian result file.

expressions

Optional named list of simulation expressions.

percentage_of_draws_to_use

Percentage of posterior draws evaluated by native Biogeme.

lower_quantile

Lower posterior-simulation quantile.

upper_quantile

Upper posterior-simulation quantile.

control

Optional biogeme_control() object.

Value

A biogeme_simulation object containing native summaries.


rbiogeme documentation built on Sept. 29, 2026, 5:09 p.m.