| bayesian_posterior_mean_by_observation | R Documentation |
Loads the NetCDF result with Biogeme's public BayesianResults API and
delegates the observation-level posterior mean calculation to native Biogeme.
No posterior-draw or ArviZ object is exposed to R.
bayesian_posterior_mean_by_observation(bayesian_results, variable_name,
control = NULL)
bayesian_results |
A |
variable_name |
Name of a stored posterior variable with one observation dimension in addition to chain and draw. |
control |
Optional native Biogeme control list. Likelihood, WAIC, and LOO calculations are disabled by default. |
A data frame indexed by the native observation coordinate, with one
column named after variable_name.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.