| biogeme_config | R Documentation |
Configuration must be performed before Python is initialized in the R
session. The default requirement is biogeme==3.3.5; use this function to
select a different compatible Biogeme requirement explicitly.
biogeme_config(python = NULL, biogeme_requirement = NULL, debug = NULL)
python |
Optional Python executable. If |
biogeme_requirement |
Python requirement passed to
|
debug |
If |
biogeme_config(python = ...) selects an existing Python interpreter; it
does not install Biogeme into that interpreter. If python is omitted,
reticulate can provision the configured requirement in its managed
environment.
The current configuration, invisibly when changes are requested and visibly otherwise.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.