| biogeme_database_extract_rows | R Documentation |
This is the R equivalent of native Database.extract_rows(). Indices are
deliberately one-based, as in the rest of the R interface, and the
original row identifiers are retained in the returned database.
biogeme_database_extract_rows(database, indices)
database_extract_rows(database, indices)
database |
A |
indices |
Unique positive one-based row indices, in the order to keep. |
A new biogeme_database containing the selected observations.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.