| biogeme_error_details | R Documentation |
Return the diagnostic details attached to a Biogeme error
biogeme_error_details(error)
error |
A condition inheriting from |
A named list with operation, suggestion, parent, and optional Python traceback details.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.