| biogeme_generic_alt_specific_catalogs | R Documentation |
This is the neutral R counterpart of native Biogeme's
generic_alt_specific_catalogs(). Each returned element is a named list
of catalogs, one for every alternative. The catalogs share one native
controller with the exact specifications generic and altspec; when
segmentations are supplied, the segmentation catalogs are nested below
that controller in the same order as native Biogeme.
biogeme_generic_alt_specific_catalogs(
generic_name,
beta_parameters,
alternatives,
potential_segmentations = NULL,
maximum_number = 5L
)
generic_alt_specific_catalogs(
generic_name,
beta_parameters,
alternatives,
potential_segmentations = NULL,
maximum_number = 5L
)
generic_name |
Shared name used for the segmentation and generic/alternative-specific controllers. |
beta_parameters |
Non-empty list of |
alternatives |
At least two unique alternative names. |
potential_segmentations |
Optional non-empty list of segmentation objects. |
maximum_number |
Maximum number of potential segmentations in one option. |
A list of named lists of catalog expressions, one list per Beta.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.