| biogeme_python | R Documentation |
Initialize and return the Python interpreter used by rbiogeme
biogeme_python()
A reticulate Python configuration object. If no interpreter was selected, reticulate may provision the configured native requirement in its managed environment.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.