| biogeme_sampling_partition | R Documentation |
Stores the strata and sample sizes used by Biogeme's sampling-of-alternatives
API. The segments must cover full_set, and no sample size may exceed
the size of its segment.
biogeme_sampling_partition(segments, sample_sizes, full_set = NULL)
segments |
A non-empty list of disjoint integer alternative-ID vectors. |
sample_sizes |
One positive sample size for each segment. |
full_set |
Optional integer vector containing the complete partition universe. |
A declarative biogeme_sampling_partition object. Native Biogeme
performs the actual random sampling when the model is estimated.
sampled_alternatives_model()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.