| check_derivatives | R Documentation |
This delegates to the public BIOGEME.check_derivatives() operation. The
complete expression tree is compiled first; no R callback is evaluated by
the derivative checker.
check_derivatives(
model,
model_name = "rbiogeme_model",
controls = list(),
control = NULL,
verbose = FALSE
)
model |
A |
model_name |
Native Biogeme model name. |
controls |
Named native Biogeme controls. |
control |
Optional |
verbose |
Whether native Biogeme should print the comparison. |
A list containing the native function value, analytical and finite difference gradients and Hessians, and their error vectors.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.