| profile_jax | R Documentation |
The complete expression tree is compiled once, then native Biogeme's
CompiledFormulaEvaluator is used for each requested evaluation mode.
Each mode is evaluated twice, matching the native profiling example's first
call and steady-state measurements. Only ordinary environment and timing
summaries cross back to R.
profile_jax(
model,
beta_values = NULL,
cases = list(
list(
label = "Function only", gradient = FALSE, hessian = FALSE, bhhh = FALSE
),
list(
label = "Function + gradient", gradient = TRUE, hessian = FALSE, bhhh = FALSE
),
list(
label = "Function + gradient + Hessian",
gradient = TRUE, hessian = TRUE, bhhh = FALSE
),
list(
label = "Function + gradient + BHHH",
gradient = TRUE, hessian = FALSE, bhhh = TRUE
)
),
model_name = "rbiogeme_model",
controls = list(),
numerically_safe = FALSE,
control = NULL
)
model |
A |
beta_values |
Named finite numeric vector of parameter values. If |
cases |
A non-empty list of named case lists. Each case has a non-empty |
model_name |
Native Biogeme model name. |
controls |
Named native Biogeme controls. |
numerically_safe |
Whether native formula evaluation uses numerical-safety transformations. |
control |
Optional |
Timing values depend on the active Python, JAX, hardware, and thread configuration. The operation is a profiling diagnostic, not an estimation operation.
An object of class biogeme_jax_profile containing the native JAX environment and serialized profile data for each case.
biogeme_control
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.