| sampled_alternatives_model | R Documentation |
Defines the protocol for a native sampling-of-alternatives model. Sampling, cross-variable expansion, likelihood construction, differentiation, and optimization are performed by native Biogeme through the Python bridge. Sampling is regenerated with recycling disabled by default.
sampled_alternatives_model(
alternatives,
individuals,
choice_column,
id_column,
utility,
partition,
biogeme_file_name,
model_type = c("logit", "nested", "cnl"),
combined_variables = list(),
mev_partition = NULL,
mev_sample_sizes = NULL,
nests = NULL,
control = NULL
)
alternatives |
Numeric data frame with one row per alternative. |
individuals |
Numeric data frame with one row per decision maker. |
choice_column |
Choice column in |
id_column |
Unique alternative-ID column in |
utility |
Complete neutral Biogeme utility expression. |
partition |
Main [ |
biogeme_file_name |
Path for the native sampled-data file. |
model_type |
One of |
combined_variables |
Optional list of [ |
mev_partition |
Optional partition used for MEV terms. |
mev_sample_sizes |
Optional MEV sample sizes. |
nests |
Nested or cross-nested nest object for the selected model type. |
control |
Optional [ |
A biogeme_sampled_alternatives_model object containing ordinary R
data and a neutral expression specification.
estimate_sampled_alternatives()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.