| simulate_bayesian | R Documentation |
Evaluates named simulation formulas over native Bayesian posterior draws and returns the native mean and quantile summaries without exposing PyMC objects.
simulate_bayesian(model, bayesian_results, expressions = NULL,
percentage_of_draws_to_use = 10, lower_quantile = 0.025,
upper_quantile = 0.975, control = NULL)
model |
A |
bayesian_results |
A |
expressions |
Optional named list of simulation expressions. |
percentage_of_draws_to_use |
Percentage of posterior draws evaluated by native Biogeme. |
lower_quantile |
Lower posterior-simulation quantile. |
upper_quantile |
Upper posterior-simulation quantile. |
control |
Optional |
A biogeme_simulation object containing native summaries.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.